# Gamertags Methods: - `client.gamertags.create_charge(\*\*params) -> None` - `client.gamertags.retrieve_by_gamertag(gamertag) -> None` - `client.gamertags.retrieve_by_zbd_id(id) -> None` - `client.gamertags.retrieve_payment(id) -> None` - `client.gamertags.send_payment(\*\*params) -> None` # LightningCharges Methods: - `client.lightning_charges.create(\*\*params) -> None` - `client.lightning_charges.retrieve(id) -> None` # InternalTransfer Methods: - `client.internal_transfer.initiate(\*\*params) -> None` # LightningAddress Methods: - `client.lightning_address.create_charge(\*\*params) -> None` - `client.lightning_address.send_payment(\*\*params) -> None` - `client.lightning_address.validate(address) -> None` # LightningStaticCharges Methods: - `client.lightning_static_charges.create(\*\*params) -> None` - `client.lightning_static_charges.retrieve(id) -> None` - `client.lightning_static_charges.update(id, \*\*params) -> None` # Vouchers Methods: - `client.vouchers.create(\*\*params) -> None` - `client.vouchers.retrieve(id) -> None` - `client.vouchers.redeem(\*\*params) -> None` - `client.vouchers.revoke(\*\*params) -> None` # WithdrawalRequests Methods: - `client.withdrawal_requests.create(\*\*params) -> None` - `client.withdrawal_requests.retrieve(id) -> None` # LightningPayments Methods: - `client.lightning_payments.retrieve(id) -> None` - `client.lightning_payments.send(\*\*params) -> None` # Wallet Methods: - `client.wallet.retrieve_balance() -> None` # Utils Methods: - `client.utils.check_ip_support(ip) -> None` - `client.utils.decode_lightning_charge(\*\*params) -> None` - `client.utils.list_prod_ips() -> None` - `client.utils.retrieve_btc_usd() -> None` # Oauth2 Methods: - `client.oauth2.create_authorization_url() -> None` - `client.oauth2.refresh_token() -> None` - `client.oauth2.retrieve_user_data() -> None` - `client.oauth2.retrieve_wallet_data() -> None` # KeysendPayments Methods: - `client.keysend_payments.send(\*\*params) -> None` # EmailPayments Methods: - `client.email_payments.send(\*\*params) -> None`